All Classes and Interfaces

Class
Description
Base class for bindable proxy factories.
Base class for Binder implementations.
A BindingTargetFactory implementation that restricts the type of binding target to a specified class and its supertypes.
Base implementation of ExtendedBindingProperties.
AbstractBinder that serves as base class for MessageChannel binders.
 
 
 
Marker interface for instances that can bind/unbind groups of inputs and outputs.
FactoryBean for instantiating the interfaces specified via EnableBinding.
A strategy interface used to bind an app interface to a logical name.
Deprecated.
As of 3.0.0 in favor if providing `spring.cloud.stream.sendto.destination` property.
Configure a new destination before it is bound.
A BeanPostProcessor that sets a BinderAwareChannelResolver on any bean of type AbstractMappingMessageRouter within the context.
Configuration for a binder instance, associating a BinderType with its configuration Properties.
 
Exception thrown to indicate a binder error (most likely a configuration error).
 
 
Spring Integration message headers for Spring Cloud Stream.
Contains the properties of a binder.
 
CompositeHealthContributor that provides binder health contributions.
A DefaultBinderFactory.Listener that provides HealthIndicator support.
 
References one or more Configuration-annotated classes which provide a context definition which contains exactly one Binder, typically for a given type of system (e.g.
A registry of BinderTypes, indexed by name.
Represents a binding between an input or output and an adapter endpoint that connects via a Binder.
Utility class for registering bean definitions for binding targets.
 
Interface for implementations that perform cleanup for binders.
ApplicationEvent fired whenever the the Binding is created.
 
Provides mappings including the default mappings.
Contains the properties of a binding.
Actuator endpoint for binding control.
 
Handles binding of input/output targets by delegating to an underlying Binder.
 
Configuration class that provides necessary beans for MessageChannel binding.
 
Lifecycle controller for the bindings.
Binding states.
Defines methods to create/configure the binding targets defined by EnableBinding.
Holds information about the binding targets exposed by the interface proxy, as well as their status.
An Endpoint that has the binding information on all the Bindable message channels.
Meta data for channels.
 
MessageChannelConfigurer that composes all the message channel configurers.
A factory for creating an instance of CompositeMessageConverter for a given target MIME type.
Represents a ConsumerDestination that provides the information about the destination that is physically provisioned through ProvisioningProvider.provisionConsumerDestination(String, String, ConsumerProperties).
ConsumerEndpointCustomizer<E extends org.springframework.integration.core.MessageProducer>
If a single bean of this type is in the application context, an inbound channel adapter created by the binder can be further customized after all the properties are set.
Common consumer properties - spring.cloud.stream.bindings.[destinationName].consumer.
Automatically starts the context after a refresh.
Exception thrown when an error is encountered during message conversion.
A custom converter for MimeType that accepts a plain java class name as a shorthand for application/x-java-object;type=the.qualified.ClassName.
Default BinderFactory implementation.
A listener that can be registered with the DefaultBinderFactory that allows the registration of additional configuration.
Default implementation of a BinderTypeRegistry.
Default implementation for a Binding.
 
The default implementation of a PollableMessageSource.
 
 
 
A Bindable that stores the dynamic destination names and handles their unbinding.
Encodes requested headers into payload with format 0xff, n(1), [ [lenHdr(1), hdr, lenValue(4), value] ... ].
Deprecated.
as of 3.1 in favor of functional programming model
Properties that extend the common binding properties for a particular binder implementation.
Extension of ConsumerProperties to be used with an ExtendedPropertiesBinder.
 
Extension of Binder that takes ExtendedConsumerProperties and ExtendedProducerProperties as arguments.
 
Interfaces which defines constants used for naming conventions used in bindings of multiple functions or functions with multiple inputs and outputs.
Internal utilities for handling generics.
 
Deprecated.
as of 3.1 in favor of functional programming model
Coordinates binding/unbinding of input binding targets in accordance to the lifecycle of the host context.
Contains the names of properties for the internal use of Spring Cloud Stream.
Handles representing any java class as a MimeType.
A marker interface designating a subscriber that must be the last.
If a single bean of this type is in the application context, listener containers created by the binder can be further customized after all the properties are set.
Configurer for PollableMessageSource.
Interface to be implemented by the classes that configure the Bindable message channels.
A StreamListenerResultAdapter used for bridging an Output MessageChannel to a bound MessageChannel.
A MessageChannelConfigurer that sets data types and message converters based on BindingProperties.contentType.
Message conversion utility methods.
An implementation of BindingTargetFactory for creating DefaultPollableMessageSources.
If a single bean of this type is in the application context, pollable message sources created by the binder can be further customized after all the properties are set.
A mutable type for allowing Binder implementations to transform and enrich message content more efficiently.
 
A MessageConverter to convert a non-String objects to a String, when expected content type is "text/plain".
Deprecated.
as of 3.1 in favor of functional programming model
Coordinates binding/unbinding of output binding targets in accordance to the lifecycle of the host context.
Utility class to determine if a binding is configured for partitioning (based on the binder properties provided in the constructor) and what partition a message should be delivered to.
Strategy for extracting a partition key from a Message.
Strategy for determining the partition to which a message should be sent.
A binder that supports pollable message sources.
A PollableSource that calls a MessageHandler with a Message.
A mechanism to poll a consumer.
 
Bindable interface with one input and one output channel.
Represents a ProducerDestination that provides the information about the destination that is physically provisioned through ProvisioningProvider.provisionProducerDestination(String, ProducerProperties).
ProducerMessageHandlerCustomizer<H extends org.springframework.messaging.MessageHandler>
If a single bean of this type is in the application context, a producing message handler created by the binder can be further customized after all the properties are set.
Common producer properties.
 
Generic unchecked exception to wrap middleware or technology specific exceptions.
Provisioning SPI that allows the users to provision destinations such as queues and topics.
When using a PollableMessageSource throw this exception to cause the current message to be requeued in the broker so that it will be redelivered on the next poll.
Bindable interface with one input channel.
Bindable interface with one output channel.
Adds a Converter from String to SpEL Expression in the context.
A simple converter from String to Expression.
Contains properties for Spring Integration settings.
Common methods that can be used across various Stream annotations.
 
A class which allows user to send data to an output binding.
 
Deprecated.
as of 3.1 in favor of functional programming model
BeanPostProcessor that handles StreamListener annotations found on bean methods.
 
 
This class contains utility methods for handling StreamListener annotated bean methods.
Strategy for adapting a method argument type annotated with Input or Output from a binding type (e.g.
A strategy for adapting the result of a StreamListener annotated method to a binding target annotated with Output.
Orchestrator used for invoking the StreamListener setup method.
Deprecated.
as of 3.0 and is not used by the framework anymore.
Marker to tag an instance of RetryTemplate to be used by the binder.
An implementation of BindingTargetFactory for creating SubscribableChannels.