Class BinderAwareChannelResolver
java.lang.Object
org.springframework.messaging.core.BeanFactoryMessageChannelDestinationResolver
org.springframework.cloud.stream.binding.BinderAwareChannelResolver
- All Implemented Interfaces:
org.springframework.beans.factory.Aware,org.springframework.beans.factory.BeanFactoryAware,org.springframework.messaging.core.DestinationResolver<org.springframework.messaging.MessageChannel>
@Deprecated
public class BinderAwareChannelResolver
extends org.springframework.messaging.core.BeanFactoryMessageChannelDestinationResolver
Deprecated.
As of 3.0.0 in favor if providing `spring.cloud.stream.sendto.destination` property.
This is primarily for function-based programming model. For StreamListener it would still be
required and thus will stay until we deprecate and eventually discontinue StreamListener
and annotation-based programming model.
A
DestinationResolver implementation that
resolves the channel from the bean factory and, if not present, creates a new channel
and adds it to the factory after binding it to the binder.- Author:
- Mark Fisher, Gary Russell, Ilayaperumal Gopinathan, Oleg Zhurakousky
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interfaceDeprecated.Configure a new destination before it is bound. -
Constructor Summary
ConstructorsConstructorDescriptionBinderAwareChannelResolver(BindingService bindingService, AbstractBindingTargetFactory<? extends org.springframework.messaging.MessageChannel> bindingTargetFactory, DynamicDestinationsBindable dynamicDestinationsBindable) Deprecated.BinderAwareChannelResolver(BindingService bindingService, AbstractBindingTargetFactory<? extends org.springframework.messaging.MessageChannel> bindingTargetFactory, DynamicDestinationsBindable dynamicDestinationsBindable, BinderAwareChannelResolver.NewDestinationBindingCallback callback) Deprecated. -
Method Summary
Modifier and TypeMethodDescriptionorg.springframework.messaging.MessageChannelresolveDestination(String channelName) Deprecated.voidsetBeanFactory(org.springframework.beans.factory.BeanFactory beanFactory) Deprecated.
-
Constructor Details
-
BinderAwareChannelResolver
public BinderAwareChannelResolver(BindingService bindingService, AbstractBindingTargetFactory<? extends org.springframework.messaging.MessageChannel> bindingTargetFactory, DynamicDestinationsBindable dynamicDestinationsBindable) Deprecated. -
BinderAwareChannelResolver
public BinderAwareChannelResolver(BindingService bindingService, AbstractBindingTargetFactory<? extends org.springframework.messaging.MessageChannel> bindingTargetFactory, DynamicDestinationsBindable dynamicDestinationsBindable, BinderAwareChannelResolver.NewDestinationBindingCallback callback) Deprecated.
-
-
Method Details
-
setBeanFactory
public void setBeanFactory(org.springframework.beans.factory.BeanFactory beanFactory) Deprecated.- Specified by:
setBeanFactoryin interfaceorg.springframework.beans.factory.BeanFactoryAware- Overrides:
setBeanFactoryin classorg.springframework.messaging.core.BeanFactoryMessageChannelDestinationResolver
-
resolveDestination
Deprecated.- Specified by:
resolveDestinationin interfaceorg.springframework.messaging.core.DestinationResolver<org.springframework.messaging.MessageChannel>- Overrides:
resolveDestinationin classorg.springframework.messaging.core.BeanFactoryMessageChannelDestinationResolver
-