- Type Parameters:
H - MessageHandler type
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface
public interface ProducerMessageHandlerCustomizer<H extends org.springframework.messaging.MessageHandler>
If a single bean of this type is in the application context, a producing message
handler created by the binder can be further customized after all the properties are
set. For example, to configure less-common properties.
- Since:
- 3.0
- Author:
- Artem Bilan