Package org.springframework.cloud.stream.provisioning
-
Interface Summary Interface Description ConsumerDestination Represents a ConsumerDestination that provides the information about the destination that is physically provisioned throughProvisioningProvider.provisionConsumerDestination(String, String, ConsumerProperties).ProducerDestination Represents a ProducerDestination that provides the information about the destination that is physically provisioned throughProvisioningProvider.provisionProducerDestination(String, ProducerProperties).ProvisioningProvider<C extends ConsumerProperties,P extends ProducerProperties> Provisioning SPI that allows the users to provision destinations such as queues and topics. -
Exception Summary Exception Description ProvisioningException Generic unchecked exception to wrap middleware or technology specific exceptions.