Uses of Package
org.springframework.cloud.stream.provisioning
-
Packages that use org.springframework.cloud.stream.provisioning Package Description org.springframework.cloud.stream.binder org.springframework.cloud.stream.provisioning -
Classes in org.springframework.cloud.stream.provisioning used by org.springframework.cloud.stream.binder Class Description ConsumerDestination Represents a ConsumerDestination that provides the information about the destination that is physically provisioned throughProvisioningProvider.provisionConsumerDestination(String, String, ConsumerProperties).ProducerDestination Represents a ProducerDestination that provides the information about the destination that is physically provisioned throughProvisioningProvider.provisionProducerDestination(String, ProducerProperties).ProvisioningProvider Provisioning SPI that allows the users to provision destinations such as queues and topics. -
Classes in org.springframework.cloud.stream.provisioning used by org.springframework.cloud.stream.provisioning Class Description ConsumerDestination Represents a ConsumerDestination that provides the information about the destination that is physically provisioned throughProvisioningProvider.provisionConsumerDestination(String, String, ConsumerProperties).ProducerDestination Represents a ProducerDestination that provides the information about the destination that is physically provisioned throughProvisioningProvider.provisionProducerDestination(String, ProducerProperties).ProvisioningException Generic unchecked exception to wrap middleware or technology specific exceptions.